@@ -1,9 +1,7 @@
 """CRUD :eMixins that can be used in Actions or Views."""
 import copy
-import json
 
 from django import forms
-from django import http
 from django.contrib.admin.models import ADDITION, CHANGE, DELETION, LogEntry
 from django.contrib.contenttypes.models import ContentType
 
@@ -16,6 +14,7 @@ class CreateMixin:
     default_template_name = 'crudlfap/create.html'
     template_name_suffixes = ['create', 'form']
     controller = 'modal'
+    action = 'click->modal#open'
     color = 'green'
     log_action_flag = ADDITION
     menus = ['model']
@@ -25,6 +24,21 @@ class CreateMixin:
         self.object = self.form.save()
         return super().form_valid()
 
+    '''
+    def form_valid_json(self):
+        detail = self.router.get('detail', None)
+        url = None
+        if detail:
+            detail = detail.clone(request=self.request, object=self.object)
+            if detail.has_perm():
+                url = detail.url()
+        return http.JsonResponse({
+            'url': url,
+            'data': data,
+            'status': 'created',
+        }, status=201)
+    '''
+
 
 class ActionMixin:
     def has_perm(self):
@@ -74,13 +88,7 @@ class DeleteMixin(ActionMixin):
         return super().form_valid()
 
     def get_success_url(self):
-        return self.request.GET.get(
-            '_next',
-            self.request.POST.get(
-                '_next',
-                self.router['list'].reverse()
-            ),
-        )
+        return self.router['list'].reverse()
 
 
 class DetailMixin:
@@ -95,44 +103,27 @@ class DetailMixin:
         """Identify the object by slug or pk in the pattern."""
         return r'<{}>'.format(cls.urlfield)
 
-    def get_JSONField_display(self, name):  # noqa
-        value = getattr(self.object, name, "")
-        formated = json.dumps(value, indent=4)
-        return f'<pre>{formated}</pre>'
-
     def get_title(self):
         return str(self.object)
 
-    def get_visible_fields(self):
-        return [
-            f.name for f in self.model._meta.fields
-            if self.fields == '__all__' or f.name not in self.exclude
-        ]
-
     def get_display_fields(self):
-        """Table field rendering"""
         self.display_fields = [
             {
                 'field': self.model._meta.get_field(field),
                 'value': self.get_field_display(field),
                 'name': field,
             }
-            for field in self.visible_fields
+            for field in (
+                [f.name for f in self.model._meta.fields]
+                if self.fields == '__all__'
+                else self.fields
+            ) if field not in self.exclude
         ]
 
     def get_field_display(self, name):
         value_getter = '_'.join(['get', name, 'display'])
         if hasattr(self.object, value_getter):
             return getattr(self.object, value_getter)()
-        if hasattr(self, value_getter):
-            return getattr(self, value_getter)()
-        type_getter = '_'.join([
-            'get',
-            type(self.model._meta.get_field(name)).__name__,
-            'display',
-        ])
-        if hasattr(self, type_getter):
-            return getattr(self, type_getter)(name)
         value = getattr(self.object, name)
         if hasattr(value, 'get_absolute_url'):
             return html.A(
@@ -141,31 +132,8 @@ class DetailMixin:
             ).render()
         return value
 
-    def get_json_fields(self):
-        return self.visible_fields
-
-    def get_FIELD_json(self, obj, field):
-        value = getattr(obj, field)
-        if self.router and type(value) in self.router.registry:
-            value = self.router.registry[type(value)].serialize(obj)
-        elif value and not isinstance(value, (str, int, float, bool)):
-            value = str(value)
-        return value
-
-    def serialize(self):
-        if self.router:
-            return self.router.serialize(self.object, self.json_fields)
-        return {
-            field: getattr(
-                self,
-                f'get_{field}_json',
-                'get_FIELD_json',
-            )(self.object, field)
-            for field in self.json_fields
-        }
-
     def json_get(self, request, *args, **kwargs):
-        return http.JsonResponse(self.serialize())
+        return {field['name']: field['value'] for field in self.display_fields}
 
 
 class HistoryMixin:
@@ -236,6 +204,11 @@ class ListMixin:
                 },
                 '400': {'description': 'Invalid status value'}
             },
+            'security': [
+                {
+                    'auth': [self.permission_fullcode]
+                }
+            ],
             'summary': self.title,
             'tags': self.swagger_tags
         }
