@@ -52,9 +52,6 @@ from django.conf import settings
 from django.db import models
 from django.urls import path
 from django.utils.module_loading import import_string
-from django.utils.safestring import mark_safe
-
-from crudlfap import html
 
 from .route import Route
 from .settings import CRUDLFAP_VIEWS
@@ -130,14 +127,6 @@ class Router(object):
 
         .. note:: The final views list is generated by the
                   :py:meth:`generate_views` method.
-
-    .. py:attribute:: fields
-
-        Fields that views should use by default.
-
-    .. py:attribute:: json_fields
-
-        Fields that the Router serializer should use by default.
     """
     views = ViewsDescriptor(
         getattr(settings, 'CRUDFLAP_VIEWS', CRUDLFAP_VIEWS)
@@ -341,24 +330,6 @@ class Router(object):
 
         return views
 
-    def get_menu_component(self, name, request, **kwargs):
-        views = self.get_menu(name, request, **kwargs)
-        buttons = []
-        for view in views:
-            button = html.Component(
-                mark_safe(f'<button class="material-icons mdc-icon-button" ryzom-id="308bade28a8c11ebad3800e18cb957e9" style="color: {getattr(view, "color", "")}; --mdc-ripple-fg-size:28px; --mdc-ripple-fg-scale:1.7142857142857142; --mdc-ripple-left:10px; --mdc-ripple-top:10px;">{getattr(view, "icon", "")}</button>'),  # noqa
-                title=view.title.capitalize(),
-                href=view.url + '?_next=' + request.path_info,
-                style='text-decoration: none',
-                tag='a',
-            )
-            if getattr(view, 'controller', None) == 'modal':
-                button.attrs.up_modal = '.main-inner'
-            else:
-                button.attrs['up-target'] = html.A.attrs['up-target']
-            buttons.append(button)
-        return html.Div(*buttons)
-
     def get_model(self):
         return None
 
@@ -424,29 +395,3 @@ class Router(object):
 
             result['properties'][field.name] = field_def
         return result
-
-    def get_json_fields(self):
-        return [
-            f.name for f in self.model._meta.fields
-        ]
-
-    def get_FIELD_json(self, obj, field):
-        value = getattr(obj, field)
-        if callable(value):
-            value = value()
-        if type(value) in self.registry:
-            value = self.registry[type(value)].serialize(value)
-        elif value and not isinstance(value, (str, int, float, bool)):
-            value = str(value)
-        return value
-
-    def serialize(self, obj, fields=None):
-        fields = fields or self.json_fields
-        return {
-            field: getattr(
-                self,
-                f'get_{field}_json',
-                self.get_FIELD_json,
-            )(obj, field)
-            for field in self.json_fields
-        }
